/*
 * Copyright (c) Huawei Technologies Co., Ltd. 2020-2021. All rights reserved.
 */

import Foundation
import AGConnectAppLinking

@objc(FlutterAGCAppLinking)

/// Provides methods to initialize AppLinking Kit and implement analysis functions.
class FlutterAGCAppLinking: NSObject{
    
    
    private lazy var viewModel: AGCAppLinkingViewModel = AGCAppLinkingViewModel()
    
    @objc func buildShortAppLinking(_ params: NSDictionary, resolve: @escaping FlutterResult) -> Void {
        
        
        viewModel.delegate = self
        viewModel.buildShortAppLinking(params, result: resolve)
    }
    
    
    @objc func buildLongAppLinking(_ params: NSDictionary, resolve: @escaping FlutterResult) -> Void {
        
        viewModel.delegate = self
        viewModel.buildLongAppLinking(params, result: resolve)
    }
    
}
extension FlutterAGCAppLinking: ViewModelDelegate {
    func postError(error: Error?, result: FlutterResult) {
        let error = error as NSError?
        if error?.userInfo["PluginException"] != nil {
            result(FlutterError(
                code: error?.userInfo["PluginException"] as? String ?? "" ,
                message: error?.localizedDescription,
                details: [
                    "exceptionType": "PluginException"
                ]))
        } else {
            result(FlutterError(
                code: error?.code.description ?? "",
                message: error?.localizedDescription,
                details: [
                    "exceptionType": "SDKException"
                ]))
        }
    }
    
    func postData(data: [String : Any], result: FlutterResult) {
        result(data)
    }
}
