/*
 * Copyright (c) Huawei Technologies Co., Ltd. 2020-2021. All rights reserved.
 */

import 'dart:async';
import 'package:flutter/services.dart';

import '../agconnect_applinking.dart';

class AGCAppLinking {
  static const MethodChannel _channel =
      const MethodChannel('com.huawei.agc.flutter.applinking_methodchannel');
  static const EventChannel _eventChannel =
      const EventChannel("com.huawei.agc.flutter.applinking_eventchannel");

  Stream<ResolvedLinkData>? _onResolvedLinkData;

  Future<ShortAppLinking> buildShortAppLinking(
      ApplinkingInfo applinkingInfo) async {
    try {
      ShortAppLinking shortAppLinking = ShortAppLinking.fromMap(await _channel
          .invokeMethod('buildShortAppLinking', applinkingInfo.toMap()));

      return shortAppLinking;
    } catch (e) {
      throw AppLinkingException.from(e);
    }
  }

  Future<LongAppLinking> buildLongAppLinking(
      ApplinkingInfo applinkingInfo) async {
    try {
      LongAppLinking appLinking = LongAppLinking.fromMap(await _channel
          .invokeMethod('buildLongAppLinking', applinkingInfo.toMap()));
      return appLinking;
    } catch (e) {
      throw AppLinkingException.from(e);
    }
  }

  Stream<ResolvedLinkData>? get onResolvedData {
    if (_onResolvedLinkData == null) {
      _onResolvedLinkData = _eventChannel
          .receiveBroadcastStream()
          .map((event) => ResolvedLinkData.fromMap(event));
    }
    return _onResolvedLinkData;
  }
}
