/*
 * Copyright (c) Huawei Technologies Co., Ltd. 2020-2021. All rights reserved.
 */

import 'dart:convert';

class ResolvedLinkData {
  int? clickTimestamp;
  Uri? deepLink;
  String? socialTitle;
  String? socialDescription;
  String? socialImageUrl;
  String? campaignName;
  String? campaignMedium;
  String? campaignSource;
  String? installSource;
  LinkType? linkType;

  ResolvedLinkData(
      {this.clickTimestamp = 0,
      this.socialTitle = "",
      this.socialDescription = "",
      this.socialImageUrl = "",
      this.deepLink,
      this.campaignName = "",
      this.campaignMedium = "",
      this.campaignSource = "",
      this.installSource = "",
      this.linkType});

  Map<String, dynamic> toMap() {
    return {
      'clickTimestamp': clickTimestamp,
      'deepLink': deepLink,
      'socialTitle': socialTitle,
      'socialDescription': socialDescription,
      'socialImageUrl': socialImageUrl,
      'campaignName': campaignName,
      'campaignMedium': campaignMedium,
      'campaignSource': campaignSource,
      'installSource': installSource,
      'linkType': linkType!.index,
    };
  }

  factory ResolvedLinkData.fromMap(Map<dynamic, dynamic>? map) {
    if (map == null) return ResolvedLinkData();

    return ResolvedLinkData(
        clickTimestamp:
            map["clickTimestamp"] == null ? null : map["clickTimestamp"],
        deepLink: map["deepLink"] == null ? null : Uri.parse(map["deepLink"]),
        socialTitle: map["socialTitle"] == null ? null : map["socialTitle"],
        socialDescription:
            map["socialDescription"] == null ? null : map["socialDescription"],
        socialImageUrl:
            map["socialImageUrl"] == null ? null : map["socialImageUrl"],
        campaignName: map["campaignName"] == null ? null : map["campaignName"],
        campaignMedium:
            map["campaignMedium"] == null ? null : map["campaignMedium"],
        campaignSource:
            map["campaignSource"] == null ? null : map["campaignSource"],
        installSource:
            map["installSource"] == null ? null : map["installSource"],
        linkType: map["linkType"] == null
            ? null
            : (map["linkType"] == 0
                ? LinkType.AppLinking
                : LinkType.UnifiedLinking));
  }

  String toJson() => json.encode(toMap());

  factory ResolvedLinkData.fromJson(String source) =>
      ResolvedLinkData.fromMap(json.decode(source));

  @override
  String toString() {
    return 'ResolvedLinkData(clickTimestamp: $clickTimestamp, '
        'deepLink: $deepLink,  '
        'socialTitle: $socialTitle, socialDescription: $socialDescription, '
        'socialImageUrl: $socialImageUrl, campaignName: $campaignName, '
        'campaignMedium: $campaignMedium, campaignSource: $campaignSource,'
        '  installSource: $installSource, linkType: $linkType)';
  }
}

enum LinkType { AppLinking, UnifiedLinking }
